@@ -1,8 +1,13 @@
 from re import findall
 from mcstatus import BedrockServer, JavaServer
-from nonebot import on_fullmatch, on_regex
-from nonebot.adapters.onebot.v11 import MessageSegment as MS, Bot
-from nonebot.adapters.onebot.v11.event import GroupMessageEvent, MessageEvent
+from nonebot import on_command, on_regex
+from nonebot.adapters.onebot.v11 import (
+    MessageSegment as MS,
+    Bot,
+    Message,
+    GroupMessageEvent,
+    MessageEvent,
+)
 from nonebot.log import logger
 from nonebot.params import RegexGroup
 from nonebot.plugin import PluginMetadata
@@ -10,15 +15,16 @@ from .config import var, pc, save_file
 from asyncio import gather
 from base64 import b64decode
 from io import BytesIO
+from typing import Union
 
 __plugin_meta__ = PluginMetadata(
     name="MC服务器查询插件",
     description="如名",
     usage=f"""插件命令如下：
-信息  # 字面意思
+信息  # 字面意思，需要加命令前缀，默认/
+信息数据  # 查看已启用群以及服务器信息，需要加命令前缀，默认/
 添加服务器  # 字面意思
 删除服务器  # 字面意思
-信息数据  # 查看已启用群以及服务器信息
 """,
 )
 
@@ -31,10 +37,10 @@ async def admin_check(event: MessageEvent, bot: Bot) -> bool:
     return bot == var.handle_bot and event.user_id == pc.mc_status_admin_qqnum
 
 
-xinxi = on_fullmatch("信息", rule=group_check)
+xinxi = on_command("信息", rule=group_check)
+list_all = on_command("信息数据", rule=admin_check)
 add_server = on_regex(r"^添加服务器\s*((\d+)\s+(\S+)\s+(\S+)\s+(\S+))?", rule=admin_check)
 del_server = on_regex(r"^删除服务器\s*((\d+)\s+(\S+))?", rule=admin_check)
-list_all = on_fullmatch("信息数据", rule=admin_check)
 
 
 @xinxi.handle()
@@ -123,7 +129,9 @@ async def handle_list_all():
     await list_all.finish(f"mc_status数据\n{msg}")
 
 
-async def check_mc_status(name: str, host: str, server_type: str) -> str:
+async def check_mc_status(
+    name: str, host: str, server_type: str
+) -> Union[str, Message]:
     try:
         if server_type == "js":
             js = await JavaServer.async_lookup(host, timeout=5)
@@ -158,7 +166,10 @@ async def check_mc_status(name: str, host: str, server_type: str) -> str:
                 icon = MS.image(BytesIO(b64decode(bb))) + "\n"
             else:
                 icon = ""
-            msg = f"{icon}名称：{name} 【{version}】\n在线：{online}  延迟：{latency}ms\n◤ {player_list} ◢"
+            msg = (
+                icon
+                + f"名称：{name} 【{version}】\n在线：{online}  延迟：{latency}ms\n◤ {player_list} ◢"
+            )
 
         else:
             if host.find(":") != -1:
